"use strict";
const visit = require('unist-util-visit');
const surfaceNewlines = require('./surface-newlines');
/**
 * Visits code elements, and ensures newlines are
 * surfaced as top-level children, rather than nested
 * within tokens as refractor does by default
 */
function rehypeSurfaceCodeNewlines() {
    return function transformer(tree) {
        visit(tree, 'element', (node) => {
            // We're looking for code elements
            // (note these are distinct from `inlineCode` elements)
            if (node.tagName !== 'code')
                return;
            // The code element must have children
            if (!node.children || node.children.length === 0)
                return;
            // Surface newlines, re-assigning to the children prop
            node.children = surfaceNewlines(node.children);
        });
    };
}
module.exports = rehypeSurfaceCodeNewlines;
